//Copyright 2023 Jerry Heinsen
//Handles the Comic.

using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;

public class ComicMasterScript : MonoBehaviour
{

//Comic.
//A Comic is multiple pages in order from Page_1 to Last.
//There is no Page_0.
//Pages are turned automatically.
//There is a brief black screen when turned, which is the Camera Background.
	public List<GameObject> Comic;

//The StartCanvas is diaplayed before Page_1
//The EndCanvas when the Comic is done.
	public GameObject StartCanvas;
	public GameObject EndCanvas;

//Don't check for ESC until ready.
	private bool DoNotUpdate = true;

//Current Page.
	private int CurrentPage;


//Start here.################################################
//The Opening Page is displayed.
	private void Start()
	{
		StartCanvas.SetActive(true);
	}

//Start Comic.
	public void StartComic()
	{
		StartCanvas.SetActive(false);
		CurrentPage = 1;
		Comic[CurrentPage].SetActive(true);
		PageScript PS = Comic[CurrentPage].GetComponent<PageScript>();
		PS.Begin();
		DoNotUpdate = false;
	}

//Check for ESC once started.
//Handle Page turns.
	private void FixedUpdate()
	{
		if (DoNotUpdate)
			return;
		if (Input.GetKey(KeyCode.Escape))
			EndComic();
	//Wait for CurrentPage to be done.
		if (Comic[CurrentPage].activeSelf)
			return;
	//All done, is this the last Page ?
		CurrentPage += 1;
	//Yes.
		if (CurrentPage >= Comic.Count)
		{
			EndCanvas.SetActive(true);
			Invoke("EndComic", 5f);
		}
	//No, wait a bit and then next page.
		else
			Invoke("NextPage", 0.5f);
		DoNotUpdate = true;
	}

	private void NextPage()
	{
		Comic[CurrentPage].SetActive(true);
		PageScript PS = Comic[CurrentPage].GetComponent<PageScript>();
		PS.Begin();
		DoNotUpdate = false;
	}

//End Comic.
	private void EndComic()
	{
		#if UNITY_EDITOR
			UnityEditor.EditorApplication.isPlaying = false;
		#endif
		Application.Quit();
	}

}
