//Copyright 2023 Jerry Heinsen
//Handles a single Page.

using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PageScript : MonoBehaviour
{

//Page.
//The Page Background is a 1920 x 1280 Sprite, a child of the Page.
//There is a StartDelay before any Dialogs.
//The SoundClip is played at Page start unless it is null.
//There can be 0 or more Dialogs that are played in order.
	public float StartDelay;
	public AudioClip SoundClip = null;
	public List<strucDialog> Dialogs;

//Dialogs.
//A Dialog is a balloon and an Audio Clip.
//The balloon is semi-transparent with Text inside, a child of the Page.
//At the end of the Clip, there is an EndDelay.
	[Serializable]
	public struct strucDialog
	{
		public GameObject Balloon;
		public AudioClip Clip;
		public float EndDelay;
	}
	private int CurrentDialog = 0;

//Procedure.
//At start, all Pages and Balloons are inActive, all Backgrounds are Active.
//Pages are set Active to display the Page, which displays the Background.
//Balloons are set Active as the Dialogs play.

//Use a simple FSM.
	private enum enumDialogState
	{
		BEGIN,			//StartDelay is done, start Dialogs
		SET,				//if more Dialogs, enable the Balloon, start the Clip
								//else set this Page inActive, Gamemaster will detect
		DELAY,			//Clip is done, start Delay
		DONE				//Delay is done, goto SET
	};
	private enumDialogState DialogState;
//Timeout from delays.
	private float TimeOut = float.MaxValue;

//References.
	private AudioSource AS;


//Start here.#########################################################
//This is called from GameMaster.
	public void Begin()
	{
 		AS = GetComponent<AudioSource>();
		DialogState = enumDialogState.BEGIN;
		TimeOut = Time.time + StartDelay;
		if (SoundClip != null)
			AS.PlayOneShot(SoundClip);
	}

//Use the Physics Update.
	private void FixedUpdate()
	{
		if (Time.time < TimeOut)
			return;
	//Time to do something.
		switch(DialogState)
		{
		//Fresh start.
			case enumDialogState.BEGIN:
				if (Dialogs.Count == 0)
					gameObject.SetActive(false);
				CurrentDialog = 0;
				DialogState = enumDialogState.SET;
				break;
		//Do Dialogs till done.
			case enumDialogState.SET:
				Dialogs[CurrentDialog].Balloon.SetActive(true);
				AS.PlayOneShot(Dialogs[CurrentDialog].Clip);
				TimeOut = Time.time + Dialogs[CurrentDialog].Clip.length;
				DialogState = enumDialogState.DELAY;
				break;
			case enumDialogState.DELAY:
				TimeOut = Time.time + Dialogs[CurrentDialog].EndDelay;
				Dialogs[CurrentDialog].Balloon.SetActive(false);
				DialogState = enumDialogState.DONE;
				break;
			case enumDialogState.DONE:
				CurrentDialog += 1;
				if (CurrentDialog >= Dialogs.Count)
					gameObject.SetActive(false);
				DialogState = enumDialogState.SET;
				break;
		}
	}
}
